# dbhydra
Data science friendly ORM combining Python, Pandas, and various SQL dialects

Aims: Easy integration with Pandas, SQL SERVER/MySQL database, and exports/imports to/from excel/CSV format

Done: Table functions (Create, Drop, Select, Update, Insert, and Delete) should be working fine

Todo: Group by, Order by, Where, Linking of FK, Customizable PK,...

Usage: Fill connection details in config.ini file, then follow the structure in hydra_model.py
